"""

"""

import os
import unittest

from altdeutsch import PACKDIR
from altdeutsch.reader import read_export

__author__ = ["Clément Besnier <clemsciences@aol.com>", ]


class UnitTest(unittest.TestCase):

    def test_hildebrandslied(self):
        res = read_export(os.path.join(PACKDIR, "tests", "data", "hildebrandslied.txt"))

        self.assertEqual(list(res.keys()),
                         ['tok', 'lemma', 'inflection', 'verse', 'edition', 'pos', 'text', 'translation',
                          'lang', 'clause', 'inflectionClass', 'posLemma', 'rhyme', 'document',
                          'inflectionClassLemma'])

        self.assertEqual(res["tok"][0], ['Ik', 'gihorta', 'ðat', 'seggen', 'ðat', 'sih', 'urhettun', 'ænon', 'muotin'])



"""

"""

import csv
import codecs

__author__ = ["Clément Besnier <clemsciences@aol.com>", ]


def read_export(filename):
    with codecs.open(filename, "r", encoding="utf-8") as f:
        reader = csv.reader(f, delimiter="\t")
        return {row[1]: [tokenize(sent) for sent in sentence_delimit(row[2])] for row in reader if len(row) > 2}


def sentence_delimit(text):
    return [token for token in text.split("·")]


def tokenize(text):
    return [token for token in text.split(" ") if token]


def render_text():
    pass
